package sun.awt.windows;

import java.awt.SystemColor;
import java.awt.Component;
import java.awt.Dimension;
import java.util.Iterator;
import sun.awt.AWTAccessor;
import java.awt.Window;
import java.util.List;
import sun.awt.im.InputMethodManager;
import java.awt.Dialog;
import java.awt.Color;
import java.awt.peer.DialogPeer;

final class WDialogPeer extends WWindowPeer implements DialogPeer
{
    static final Color defaultBackground;
    boolean needDefaultBackground;
    
    WDialogPeer(Dialog dialog) {
        super(dialog);
        String triggerMenuString = InputMethodManager.getInstance().getTriggerMenuString();
        if (triggerMenuString != null) {
            this.pSetIMMOption(triggerMenuString);
        }
    }
    
    native void createAwtDialog(WComponentPeer p0);
    
    @Override
    void create(WComponentPeer wComponentPeer) {
        this.preCreate(wComponentPeer);
        this.createAwtDialog(wComponentPeer);
    }
    
    native void showModal();
    
    native void endModal();
    
    @Override
    void initialize() {
        Dialog dialog = (Dialog)this.target;
        if (this.needDefaultBackground) {
            dialog.setBackground(WDialogPeer.defaultBackground);
        }
        super.initialize();
        if (dialog.getTitle() != null) {
            this.setTitle(dialog.getTitle());
        }
        this.setResizable(dialog.isResizable());
    }
    
    @Override
    protected void realShow() {
        if (((Dialog)this.target).getModalityType() != Dialog.ModalityType.MODELESS) {
            this.showModal();
        }
        else {
            super.realShow();
        }
    }
    
    @Override
    void hide() {
        if (((Dialog)this.target).getModalityType() != Dialog.ModalityType.MODELESS) {
            this.endModal();
        }
        else {
            super.hide();
        }
    }
    
    @Override
    public void blockWindows(List<Window> list) {
        Iterator<Object> iterator = list.iterator();
        while (iterator.hasNext()) {
            WWindowPeer wWindowPeer = (WWindowPeer)AWTAccessor.getComponentAccessor().getPeer((Window)iterator.next());
            if (wWindowPeer != null) {
                wWindowPeer.setModalBlocked((Dialog)this.target, true);
            }
            else {
                continue;
            }
        }
    }
    
    @Override
    public Dimension getMinimumSize() {
        if (((Dialog)this.target).isUndecorated()) {
            return super.getMinimumSize();
        }
        return new Dimension(WWindowPeer.getSysMinWidth(), WWindowPeer.getSysMinHeight());
    }
    
    @Override
    boolean isTargetUndecorated() {
        return ((Dialog)this.target).isUndecorated();
    }
    
    @Override
    public void reshape(int n, int n2, int n3, int n4) {
        if (((Dialog)this.target).isUndecorated()) {
            super.reshape(n, n2, n3, n4);
        }
        else {
            this.reshapeFrame(n, n2, n3, n4);
        }
    }
    
    private void setDefaultColor() {
        this.needDefaultBackground = true;
    }
    
    native void pSetIMMOption(String p0);
    
    void notifyIMMOptionChange() {
        InputMethodManager.getInstance().notifyChangeRequest((Component)this.target);
    }
    
    static {
        defaultBackground = SystemColor.control;
    }
}
